import httpRequest from '@/utils/axios'
import type {
  ContestCreateParams,
  ContestUpdateParams,
  ContestBookUpdateParams,
  ContestVideoCreateParams,
  ContestVideoUpdateParams
} from './types'

// 获取赛项列表
export function getContestItemList(params?: { page?: number; 'per-page'?: number }) {
  return httpRequest.get('/api/resource/v1/backend/competition/list', { params })
}

// 获取赛项详情
export function getContestItem(params: { id: string }) {
  return httpRequest.get('/api/resource/v1/backend/competition/detail', { params })
}

// 创建赛项
export function createContest(data: ContestCreateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition/create', data)
}

// 更新赛项
export function updateContest(data: ContestUpdateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition/update', data)
}

// 获取指导老师列表
export function getTeacherList(params?: { name?: string }) {
  return httpRequest.get('/api/resource/v1/backend/teacher/faculty-advisers', { params })
}

// 更新评分规则
export function updateContestRules(data: ContestUpdateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition-rule/save', data)
}

// 获取赛项指导书详情
export function getContestBook(params: { competition_id: string }) {
  return httpRequest.get('/api/resource/v1/backend/competition-book/detail', { params })
}
// 添加赛项指导书
export function createContestBook(data: ContestBookUpdateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition-book/create', data)
}
// 更新赛项指导书
export function updateContestBook(data: ContestBookUpdateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition-book/update', data)
}
// 删除赛项指导书
export function deleteContestBook(data: { competition_id: string }) {
  return httpRequest.post('/api/resource/v1/backend/competition-book/delete', data)
}

// 获取赛项操作视频列表
export function getContestVideoList(params: { competition_id: string }) {
  return httpRequest.get('/api/resource/v1/backend/competition-video/list', { params })
}
// 获取赛项操作视频详情
export function getContestVideo(params: { competition_id: string }) {
  return httpRequest.get('/api/resource/v1/backend/competition-video/detail', { params })
}
// 获取赛项操作视频详情
export function getContestVideoPalyInfo(params: { source_id: string }) {
  return httpRequest.get('/api/resource/v1/backend/competition-video/replay-list', { params })
}
// 添加赛项操作视频
export function createContestVideo(data: ContestVideoCreateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition-video/create', data)
}
// 更新赛项操作视频
export function updateContestVideo(data: ContestVideoUpdateParams) {
  return httpRequest.post('/api/resource/v1/backend/competition-video/update', data)
}
// 删除赛项操作视频
export function deleteContestVideo(data: { id: string }) {
  return httpRequest.post('/api/resource/v1/backend/competition-video/delete', data)
}
